const Meta = imports.gi.Meta;
const Gio  = imports.gi.Gio;
const Shell = imports.gi.Shell;

const Main = imports.ui.main;

const Utils = imports.misc.extensionUtils.getCurrentExtension().imports.utils; 

// End of imports.

const TERMINAL_SCHEMA = 'org.gnome.desktop.default-applications.terminal';

const mySettings = Utils.getSettings();

const key_bindings = {
	// All

	'show-looking-glass': function() {
		Main.createLookingGlass().open();
	},

	'open-terminal': function() {
		let termSettings = new Gio.Settings({ 'schema': TERMINAL_SCHEMA });
		try {
			imports.misc.util.trySpawnCommandLine(termSettings.get_string('exec'));
		} catch(e) {
			logError(e, 'Error launching terminal')
		}
	},
	
	// 3.6	

	'activate-message-tray': function() {
		let noti = Main.messageTray._notification;
		if(noti != null) {
			Main.messageTray._expandNotification(false);
		}
	},

	// 3.4

	'show-message-tray': function() {
		Main.messageTray.toggle();
	}
};

const modes = {
	'open-terminal': Shell.KeyBindingMode.NORMAL,
	'show-looking-glass': Shell.KeyBindingMode.NORMAL | Shell.KeyBindingMode.OVERVIEW
}

function init(metadata) {

}

function enable() {
	let binds = Utils.getKeyBindings();

	for(i in binds) {
		let key = binds[i];

		if(Main.wm.addKeybinding) {
			Main.wm.addKeybinding(key, mySettings,
				Meta.KeyBindingFlags.NONE,
				modes[key],
				key_bindings[key]
			)
		} else {
			global.display.add_keybinding(key,
				mySettings,
				Meta.KeyBindingFlags.NONE,
				key_bindings[key]
			);
		}
	}
}

function disable() {
	let binds = Utils.getKeyBindings();

	for(i in binds) {
		let key = binds[i];
		global.display.remove_keybinding(key);
	}
}
